@@ -53,7 +53,7 @@
 
 void run_event_loop_impl(struct getdns_context* context, void* eventloop) {
     struct ev_loop* loop = (struct ev_loop*) eventloop;
-    (void)context;
+    (void)context; /* unused parameter */
     ev_run(loop, 0);
 }
 
