@@ -170,7 +170,8 @@
      {
        assert_nxdomain(ex_response);
        assert_nodata(ex_response);
-       assert_soa_in_authority(ex_response);
+       // Ubuntu 18.04 system resolver does not return an SOA
+       //assert_soa_in_authority(ex_response);
      }
 
 
